pub struct AccessPath {
pub address: AccountAddress,
pub path: Vec<u8>,
}Fields
address: AccountAddresspath: Vec<u8>Implementations
Sourceimpl AccessPath
impl AccessPath
pub fn new(address: AccountAddress, path: Vec<u8>) -> Self
pub fn resource_access_vec(tag: StructTag) -> Vec<u8> ⓘ
Sourcepub fn resource_access_path(key: ResourceKey) -> AccessPath
pub fn resource_access_path(key: ResourceKey) -> AccessPath
Convert Accesses into a byte offset which would be used by the storage layer to resolve where fields are stored.
pub fn code_access_path(key: ModuleId) -> AccessPath
Sourcepub fn get_struct_tag(&self) -> Option<StructTag>
pub fn get_struct_tag(&self) -> Option<StructTag>
Extract a StructTag from self. Returns Some if this is a resource access
path and None otherwise