EventWithProof

Struct EventWithProof 

pub struct EventWithProof<T> {
    pub transaction_version: u64,
    pub event_index: u64,
    pub event: ContractEvent,
    pub proof: EventProof<T>,
}

Fields

transaction_version: u64event_index: u64event: ContractEventproof: EventProof<T>

Implementations

Source

impl<T: TransactionInfoTrait> EventWithProof<T>

pub fn new( transaction_version: Version, event_index: u64, event: ContractEvent, proof: EventProof<T>, ) -> Self

Constructor.

pub fn verify( &self, ledger_info: &LedgerInfo, event_key: &EventKey, sequence_number: u64, transaction_version: Version, event_index: u64, ) -> Result<()>

Verifies the event with the proof, both carried by self.

Two things are ensured if no error is raised:

  1. This event exists in the ledger represented by ledger_info.
  2. And this event has the same event_key, sequence_number, transaction_version, and event_index as indicated in the parameter list. If any of these parameter is unknown to the call site and is supposed to be informed by this struct, get it from the struct itself, such as: event_with_proof.event.access_path(), event_with_proof.event_index(), etc.