pub struct EventKey(/* private fields */);Expand description
A struct that represents a globally unique id for an Event stream that a user can listen to. By design, the lower part of EventKey is the same as account address.
Implementations
Sourceimpl EventKey
impl EventKey
Sourcepub fn get_creator_address(&self) -> AccountAddress
pub fn get_creator_address(&self) -> AccountAddress
Get the account address part in this event key
Sourcepub fn get_creation_number(&self) -> u64
pub fn get_creation_number(&self) -> u64
If this is the ith EventKeycreated byget_creator_address(), return i`
Sourcepub fn new_from_address(addr: &AccountAddress, salt: u64) -> Self
pub fn new_from_address(addr: &AccountAddress, salt: u64) -> Self
Create a unique handle by using an AccountAddress and a counter.
pub fn from_hex<T: AsRef<[u8]>>(hex: T) -> Result<Self, EventKeyParseError>
pub fn from_bytes<T: AsRef<[u8]>>(bytes: T) -> Result<Self, EventKeyParseError>