pub struct NibblePath { /* private fields */ }Expand description
NibblePath defines a path in Merkle tree in the unit of nibble (4 bits).
Implementations
Sourceimpl NibblePath
impl NibblePath
Sourcepub fn new(bytes: Vec<u8>) -> Self
pub fn new(bytes: Vec<u8>) -> Self
Creates a new NibblePath from a vector of bytes assuming each byte has 2 nibbles.
Sourcepub fn new_odd(bytes: Vec<u8>) -> Self
pub fn new_odd(bytes: Vec<u8>) -> Self
Similar to new() but assumes that the bytes have one less nibble.
Sourcepub fn get_nibble(&self, i: usize) -> Nibble
pub fn get_nibble(&self, i: usize) -> Nibble
Get the i-th nibble.
Sourcepub fn bits(&self) -> BitIterator<'_> ⓘ
pub fn bits(&self) -> BitIterator<'_> ⓘ
Get a bit iterator iterates over the whole nibble path.
Sourcepub fn nibbles(&self) -> NibbleIterator<'_> ⓘ
pub fn nibbles(&self) -> NibbleIterator<'_> ⓘ
Get a nibble iterator iterates over the whole nibble path.
Sourcepub fn num_nibbles(&self) -> usize
pub fn num_nibbles(&self) -> usize
Get the total number of nibbles stored.