WriteSet

Struct WriteSet 

pub struct WriteSet(/* private fields */);
WriteSet contains all access paths that one transaction modifies. Each of them is a WriteOp where Value(val) means that serialized representation should be updated to val, and Deletion means that we are going to delete this access path.

Implementations

Source

impl WriteSet

pub fn is_empty(&self) -> bool

pub fn iter(&self) -> Iter<'_, (AccessPath, WriteOp)>

pub fn into_mut(self) -> WriteSetMut