pub struct BlockMetadata { /* private fields */ }Expand description
Struct that will be persisted on chain to store the information of the current block.
The flow will look like following:
- The executor will pass this struct to VM at the end of a block proposal.
- The VM will use this struct to create a special system transaction that will emit an event represents the information of the current block. This transaction can’t be emitted by regular users and is generated by each of the validators on the fly. Such transaction will be executed before all of the user-submitted transactions in the blocks.
- Once that special resource is modified, the other user transactions can read the consensus info by calling into the read method of that resource, which would thus give users the information such as the current leader.
Implementations
Sourceimpl BlockMetadata
impl BlockMetadata
pub fn new( id: HashValue, round: u64, timestamp_usecs: u64, previous_block_votes: Vec<AccountAddress>, proposer: AccountAddress, ) -> Self
pub fn id(&self) -> HashValue
pub fn into_inner(self) -> (u64, u64, Vec<AccountAddress>, AccountAddress)
pub fn timestamp_usec(&self) -> u64
pub fn proposer(&self) -> AccountAddress
pub fn previous_block_votes(&self) -> &Vec<AccountAddress>
pub fn round(&self) -> u64