pub struct EventByVersionWithProof<T> {
pub lower_bound_incl: Option<EventWithProof<T>>,
pub upper_bound_excl: Option<EventWithProof<T>>,
}Expand description
The response type for get_event_by_version_with_proof, which contains lower
and upper bound events surrounding the requested version along with proofs
for each event.
Why do we need two events?
If we could always get the event count at the requested event_version, we
could return only the lower bound event. With the event count we could verify
that the returned event is actually the latest event at the historical ledger
view just by checking that event.sequence_number == event_count.
Unfortunately, the event count is only (verifiably) accessible via the on-chain state. While we can easily acquire the event count near the chain HEAD, historical event counts (at versions below HEAD for more than the prune window) may be inaccessible after most non-archival fullnodes have pruned past that version.
Including the Upper Bound Event
In contrast, if we also return the upper bound event, then we can always verify the request even if the version is past the prune window and we don’t know the event_count (at event_version). The upper bound event lets us prove that there is no untransmitted event that is actually closer to the requested event_version than the lower bound.
For example, consider the case where there are three events at versions 10, 20, and 30. A client asks for the latest event at or below version 25. If we just returned the lower bound event, then a malicious server could return the event at version 10; the client would not be able to distinguish this response from the correct response without the event count (2) at version 25.
If we also return the upper bound event (the event at version 30), the client can verify that the upper bound is the next event after the lower bound and that the upper bound comes after their requested version. This proves that the lower bound is actually the latest event at or below their requested version.
Fields
lower_bound_incl: Option<EventWithProof<T>>upper_bound_excl: Option<EventWithProof<T>>Implementations
Sourceimpl<T: TransactionInfoTrait> EventByVersionWithProof<T>
impl<T: TransactionInfoTrait> EventByVersionWithProof<T>
pub fn new( lower_bound_incl: Option<EventWithProof<T>>, upper_bound_excl: Option<EventWithProof<T>>, ) -> Self
Sourcepub fn verify(
&self,
ledger_info: &LedgerInfo,
event_key: &EventKey,
latest_event_count: Option<u64>,
event_version: Version,
) -> Result<()>
pub fn verify( &self, ledger_info: &LedgerInfo, event_key: &EventKey, latest_event_count: Option<u64>, event_version: Version, ) -> Result<()>
Verify that the lower_bound_incl EventWithProof is the latest event
at or below the requested event_version.
The ledger_info is the client’s latest know ledger info (will be near
chain HEAD if the client is synced).
The latest_event_count is the event count at the ledger_info version
(not the event_version) and is needed to verify the empty event stream
and version after last event cases. In some select instances
(e.g. NewBlockEvents) we can determine these cases more efficiently
and so this parameter is left optional.