pub struct EventWithProof<T> {
pub transaction_version: u64,
pub event_index: u64,
pub event: ContractEvent,
pub proof: EventProof<T>,
}Fields
transaction_version: u64event_index: u64event: ContractEventproof: EventProof<T>Implementations
Sourceimpl<T: TransactionInfoTrait> EventWithProof<T>
impl<T: TransactionInfoTrait> EventWithProof<T>
Sourcepub fn new(
transaction_version: Version,
event_index: u64,
event: ContractEvent,
proof: EventProof<T>,
) -> Self
pub fn new( transaction_version: Version, event_index: u64, event: ContractEvent, proof: EventProof<T>, ) -> Self
Constructor.
Sourcepub fn verify(
&self,
ledger_info: &LedgerInfo,
event_key: &EventKey,
sequence_number: u64,
transaction_version: Version,
event_index: u64,
) -> Result<()>
pub fn verify( &self, ledger_info: &LedgerInfo, event_key: &EventKey, sequence_number: u64, transaction_version: Version, event_index: u64, ) -> Result<()>
Verifies the event with the proof, both carried by self.
Two things are ensured if no error is raised:
- This event exists in the ledger represented by
ledger_info. - And this event has the same
event_key,sequence_number,transaction_version, andevent_indexas indicated in the parameter list. If any of these parameter is unknown to the call site and is supposed to be informed by this struct, get it from the struct itself, such as:event_with_proof.event.access_path(),event_with_proof.event_index(), etc.